CredentialInfo class

Constructors

CredentialInfo({required String createdAt, required String displayName, required String id, required List<String> transport})
const
CredentialInfo.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited