EntitlementResponse class

Constructors

EntitlementResponse({required bool allowed, required String feature, required int limit, String? reason, required int remaining, required int used})
const
EntitlementResponse.fromJson(Map<String, dynamic> json)
factory

Properties

allowed bool
final
feature String
final
hashCode int
The hash code for this object.
no setterinherited
limit int
final
reason String?
final
remaining int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
used int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited