IntrospectResponse class

Constructors

IntrospectResponse({required bool active, String? appId, String? envId, String? expiresAt, String? orgId, String? sessionId, IntrospectUser? user, String? userId})
const
IntrospectResponse.fromJson(Map<String, dynamic> json)
factory

Properties

active bool
final
appId String?
final
envId String?
final
expiresAt String?
final
hashCode int
The hash code for this object.
no setterinherited
orgId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
user IntrospectUser?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited