AdminServiceAccountAPIKeyResponse class
Constructors
-
AdminServiceAccountAPIKeyResponse({required String createdAt, String? expiresAt, required String id, required String key, required String keyPrefix, required String name, String? publicKey, String? publicKeyPrefix, List<
String> ? scopes}) -
const
-
AdminServiceAccountAPIKeyResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → String
-
final
- expiresAt → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- key → String
-
final
- keyPrefix → String
-
final
- name → String
-
final
- publicKey → String?
-
final
- publicKeyPrefix → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited