EntitlementResponse class
Constructors
- EntitlementResponse({required bool allowed, required String feature, required int limit, String? reason, required int remaining, required int used})
-
const
-
EntitlementResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited