User class
Constructors
-
User({required String appId, String? banExpires, String? banReason, required bool banned, required String createdAt, String? deletedAt, String? displayUsername, required String email, required bool emailVerified, required String envId, required String firstName, required String id, String? image, required String lastName, Map<
String, dynamic> ? metadata, String? passwordChangedAt, String? phone, required bool phoneVerified, required String updatedAt, String? username}) -
const
-
User.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appId → String
-
final
- banExpires → String?
-
final
- banned → bool
-
final
- banReason → String?
-
final
- createdAt → String
-
final
- deletedAt → String?
-
final
- displayUsername → String?
-
final
- email → String
-
final
- emailVerified → bool
-
final
- envId → String
-
final
- firstName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- image → String?
-
final
- lastName → String
-
final
-
metadata
→ Map<
String, dynamic> ? -
final
- passwordChangedAt → String?
-
final
- phone → String?
-
final
- phoneVerified → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → String
-
final
- username → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited